aboutsummaryrefslogtreecommitdiff
path: root/engines/draci/surface.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/draci/surface.h')
-rw-r--r--engines/draci/surface.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/engines/draci/surface.h b/engines/draci/surface.h
index a5c9ddb597..cb15ecebe4 100644
--- a/engines/draci/surface.h
+++ b/engines/draci/surface.h
@@ -27,6 +27,7 @@
#define DRACI_SURFACE_H
#include "common/list.h"
+#include "common/rect.h"
#include "graphics/surface.h"
namespace Draci {
@@ -43,18 +44,18 @@ public:
void markDirty();
void markClean();
bool needsFullUpdate() const { return _fullUpdate; }
- uint getTransparentColour() const { return _transparentColour; }
- void setTransparentColour(uint colour) { _transparentColour = colour; }
- void fill(uint colour);
+ uint getTransparentColor() const { return _transparentColor; }
+ void setTransparentColor(uint color) { _transparentColor = color; }
+ void fill(uint color);
uint putAboveY(int y, int height) const;
uint centerOnX(int x, int width) const;
Common::Rect getDimensions() const { return Common::Rect(w, h); }
private:
/** The current transparent colour of the surface. See getTransparentColour() and
* setTransparentColour().
*/
- uint _transparentColour;
+ uint _transparentColor;
/** Set when the surface is scheduled for a full update.
* See markDirty(), markClean(). Accessed via needsFullUpdate().
@@ -43,18 +44,18 @@ public:
Common::Rect getDimensions() const { return Common::Rect(w, h); }
private:
- /** The current transparent colour of the surface. See getTransparentColour() and
- * setTransparentColour().
+ /** The current transparent color of the surface. See getTransparentColor() and
+ * setTransparentColor().
*/